@@ -18,6 +18,16 @@
 // Qt
 #include <QVector>
 
+/* clang-format off */
+const int LINE_WRAPPED              = (1 << 0);
+const int LINE_DOUBLEWIDTH          = (1 << 1);
+const int LINE_DOUBLEHEIGHT_TOP     = (1 << 2);
+const int LINE_DOUBLEHEIGHT_BOTTOM  = (1 << 3);
+const int LINE_PROMPT_START         = (1 << 4);
+const int LINE_INPUT_START          = (1 << 5);
+const int LINE_OUTPUT_START         = (1 << 6);
+/* clang-format on */
+
 namespace Konsole
 {
 #pragma pack(1)
@@ -50,6 +60,18 @@ public:
     {
         return (flags.all != rhs.flags.all);
     }
+    void resetStarts()
+    {
+        flags.all &= ~(LINE_PROMPT_START | LINE_INPUT_START | LINE_OUTPUT_START);
+    }
+    quint16 getStarts() const
+    {
+        return flags.all & (LINE_PROMPT_START | LINE_INPUT_START | LINE_OUTPUT_START);
+    }
+    void setStarts(quint16 starts)
+    {
+        flags.all = (flags.all & ~(LINE_PROMPT_START | LINE_INPUT_START | LINE_OUTPUT_START)) | starts;
+    }
 };
 
 typedef union {
@@ -76,14 +98,6 @@ typedef quint16 RenditionFlags;
 typedef quint16 ExtraFlags;
 
 /* clang-format off */
-const int LINE_WRAPPED              = (1 << 0);
-const int LINE_DOUBLEWIDTH          = (1 << 1);
-const int LINE_DOUBLEHEIGHT_TOP     = (1 << 2);
-const int LINE_DOUBLEHEIGHT_BOTTOM  = (1 << 3);
-const int LINE_PROMPT_START         = (1 << 4);
-const int LINE_INPUT_START          = (1 << 5);
-const int LINE_OUTPUT_START         = (1 << 6);
-
 const RenditionFlags DEFAULT_RENDITION  = 0;
 const RenditionFlags RE_BOLD            = (1 << 0);
 const RenditionFlags RE_BLINK           = (1 << 1);
@@ -168,7 +182,7 @@ public:
      * look up the unicode character sequence in the ExtendedCharTable used to
      * create the sequence.
      */
-    uint character;
+    char32_t character;
 
     /** A combination of RENDITION flags which specify options for drawing the character. */
     RenditionFlagsC rendition;
@@ -208,7 +222,7 @@ public:
         if (rendition.f.extended) {
             return false;
         } else {
-            return QChar(character).isSpace();
+            return QChar::isSpace(character);
         }
     }
 
@@ -249,9 +263,9 @@ public:
     static bool emojiPresentation(uint ucs4)
     {
         if (ucs4 >= emojiPresentation1Start && ucs4 <= emojiPresentation1End) {
-            return (emojiPresentation1Bits[(ucs4 - emojiPresentation1Start) / 64] & (1l << ((ucs4 - emojiPresentation1Start) % 64))) != 0;
+            return (emojiPresentation1Bits[(ucs4 - emojiPresentation1Start) / 64] & (uint64_t(1) << ((ucs4 - emojiPresentation1Start) % 64))) != 0;
         } else if (ucs4 >= emojiPresentation2Start && ucs4 <= emojiPresentation2End) {
-            return (emojiPresentation2Bits[(ucs4 - emojiPresentation2Start) / 64] & (1l << ((ucs4 - emojiPresentation2Start) % 64))) != 0;
+            return (emojiPresentation2Bits[(ucs4 - emojiPresentation2Start) / 64] & (uint64_t(1) << ((ucs4 - emojiPresentation2Start) % 64))) != 0;
         }
         return false;
     }
@@ -288,9 +302,9 @@ public:
     static bool emoji(uint ucs4)
     {
         if (ucs4 >= emoji1Start && ucs4 <= emoji1End) {
-            return (emoji1Bits[(ucs4 - emoji1Start) / 64] & (1l << ((ucs4 - emoji1Start) % 64))) != 0;
+            return (emoji1Bits[(ucs4 - emoji1Start) / 64] & (uint64_t(1) << ((ucs4 - emoji1Start) % 64))) != 0;
         } else if (ucs4 >= emoji2Start && ucs4 <= emoji2End) {
-            return (emoji2Bits[(ucs4 - emoji2Start) / 64] & (1l << ((ucs4 - emoji2Start) % 64))) != 0;
+            return (emoji2Bits[(ucs4 - emoji2Start) / 64] & (uint64_t(1) << ((ucs4 - emoji2Start) % 64))) != 0;
         }
         return false;
     }
@@ -315,7 +329,7 @@ public:
         return characterWidth(ucs4);
     }
 
-    static int stringWidth(const uint *ucs4Str, int len)
+    static int stringWidth(const char32_t *ucs4Str, int len)
     {
         int w = 0;
         Hangul::SyllablePos hangulSyllablePos = Hangul::NotInSyllable;
@@ -335,15 +349,15 @@ public:
 
     inline static int stringWidth(const QString &str)
     {
-        QVector<uint> ucs4Str = str.toUcs4();
-        return stringWidth(ucs4Str.constData(), ucs4Str.length());
+        const auto ucs4Str = str.toStdU32String();
+        return stringWidth(ucs4Str.data(), ucs4Str.size());
     }
 
     inline uint baseCodePoint() const
     {
         if (rendition.f.extended) {
             ushort extendedCharLength = 0;
-            const uint *chars = ExtendedCharTable::instance.lookupExtendedChar(character, extendedCharLength);
+            const char32_t *chars = ExtendedCharTable::instance.lookupExtendedChar(character, extendedCharLength);
             // FIXME: Coverity-Dereferencing chars, which is known to be nullptr
             return chars[0];
         }
